@@ -26,27 +26,31 @@ ARCHITECTURE_NAME_MAP = {
 }
 SUPPORTED_ARCHITECTURES = tuple(ARCHITECTURE_NAME_MAP.keys())
 
-SUPPORTED_ROS2_DISTROS = ('dashing', 'eloquent', 'foxy')
-SUPPORTED_ROS_DISTROS = ('kinetic', 'melodic')
+SUPPORTED_ROS2_DISTROS = ('dashing', 'foxy', 'galactic', 'rolling')
+SUPPORTED_ROS_DISTROS = ('melodic', 'noetic')
 
 ROSDISTRO_OS_MAP = {
-    'kinetic': {
-        'ubuntu': 'xenial',
-        'debian': 'jessie',
-    },
     'melodic': {
         'ubuntu': 'bionic',
         'debian': 'stretch',
     },
+    'noetic': {
+        'ubuntu': 'focal',
+        'debian': 'buster',
+    },
     'dashing': {
         'ubuntu': 'bionic',
         'debian': 'stretch',
     },
-    'eloquent': {
-        'ubuntu': 'bionic',
+    'foxy': {
+        'ubuntu': 'focal',
         'debian': 'buster',
     },
-    'foxy': {
+    'galactic': {
+        'ubuntu': 'focal',
+        'debian': 'buster',
+    },
+    'rolling': {
         'ubuntu': 'focal',
         'debian': 'buster',
     },
